<?php
/**
 * Stripe Payment Method
 * 
 * @package Eventin Pro
 */

namespace EventinPro\Integrations\Stripe;

use Eventin\Order\OrderModel;
use Eventin\Order\PaymentInterface;
use WP_Error;

class StripePayment implements PaymentInterface {
    /**
     * Store stripe object
     *
     * @var Stripe
     */
    private $stripe;

    public function __construct() {
        $secret = etn_get_option('stripe_live_secret_key');

        if ( ! $secret ) {
            return new WP_Error( 'secret_key_error', 'You must provide stripe secret key' );
        }

        $this->stripe = new Stripe( $secret );
    }

    /**
     * Create payment using stripe
     *
     * @param   OrderModel  $order  Order object which need to be
     *
     * @return  string
     */
    public function create_payment( OrderModel $order ) {
        $response = $this->stripe->create_payment([
            'amount'    => $order->total_price,
            'currency'  => etn_get_option( 'etn_settings_country_currency', 'USD' ),
        ]);

        return $response;
    }

     /**
     * Create refund for woocommere order
     *
     * @param   OrderModel  $order
     *
     * @return
     */
    public function refund( OrderModel $order ) {
        return $this->stripe->create_refund( $order->payment_id );
    }
}
